# Remove private provides from .so files in the python_sitearch directory
%global __provides_exclude_from ^%{python_sitearch}/.*\\.so$

Name:           xpra
Version:        0.8.8
Release:        3%{?dist}
Summary:        screen for X

License:        GPLv2+
URL:            http://www.xpra.org/
Source0:        http://xpra.org/src/%{name}-%{version}.tar.xz

BuildRequires:  python2-devel pygobject2-devel pygtk2-devel
BuildRequires:  libXtst-devel
BuildRequires:  Cython
BuildRequires:  desktop-file-utils

Requires:       python-imaging
Requires:       dbus-python
Requires:       xorg-x11-server-utils xorg-x11-server-Xvfb
Requires:       xorg-x11-drv-dummy xorg-x11-drv-void
Requires:       PyOpenGL pygtkglext
Requires:       python-numeric numpy
Requires:       gstreamer gstreamer-python
Requires:       gstreamer-plugins-base gstreamer-plugins-good
Requires:       pulseaudio pulseaudio-utils

Requires:       python-wimpiggy == %{version}-%{release}

%description
Xpra is "screen for X": it allows you to run X programs, usually on a remote
host, direct their display to your local machine, and then to disconnect from
these programs and reconnect from the same or another machine, without losing
any state. It gives you remote access to individual applications.

Xpra is "rootless" or "seamless": programs you run under it show up on your
desktop as regular programs, managed by your regular window manager.
Sessions can be accessed over SSH, or password protected over plain TCP sockets.
Xpra is usable over reasonably slow links and does its best to adapt to changing
network bandwidth constraints.

%package -n parti
Summary:        Tabbing/tiling window manager
Requires:       python-wimpiggy == %{version}-%{release}
Requires:       dbus-python

%description -n parti
Parti is a tabbing/tiling (one might say "partitioning") window
manager.  Its goal is to bring this superior window management
interface to modern, mainstream desktop environments.

%package -n python-wimpiggy
Summary:        Library for creating window managers

Requires:       pygobject2 pygtk2 pycairo

%description -n python-wimpiggy
A library to make writing EWMH-compliant, compositing
window managers just as easy as writing an app in PyGTK+.


%prep
%setup -q
patch -p1 -i patches/disable-x264.patch
patch -p1 -i patches/disable-vpx.patch

%build
CFLAGS="%{optflags}" %{__python} setup.py build


%install
rm -rf %{buildroot}
%{__python} setup.py install --skip-build --root %{buildroot}

#move icon to proper directory
mkdir -p %{buildroot}%{_datadir}/icons/hicolor/48x48/apps
mv %{buildroot}%{_datadir}/icons/xpra.png \
    %{buildroot}%{_datadir}/icons/hicolor/48x48/apps/

#remove doc stuff from /usr/share
rm -rf \
    %{buildroot}%{_datadir}/parti \
    %{buildroot}%{_datadir}/xpra/xpra.README \
    %{buildroot}%{_datadir}/xpra/COPYING \
    %{buildroot}%{_datadir}/xpra/webm \
    %{buildroot}%{_datadir}/wimpiggy

#drop shebangs from python_sitearch
sed -i '1{\@^#!/usr/bin/env python@d}' \
    %{buildroot}%{python_sitearch}/xpra/sound/sink.py \
    %{buildroot}%{python_sitearch}/xpra/gl/gl_check.py \
    %{buildroot}%{python_sitearch}/xpra/sound/gstreamer_util.py \
    %{buildroot}%{python_sitearch}/xpra/sound/src.py \
    %{buildroot}%{python_sitearch}/xpra/keys.py \
    %{buildroot}%{python_sitearch}/xpra/stats/__init__.py \
    %{buildroot}%{python_sitearch}/xpra/nested_main.py \
    %{buildroot}%{python_sitearch}/xpra/sound/sound_pipeline.py \
    %{buildroot}%{python_sitearch}/xpra/sound/__init__.py \
    %{buildroot}%{python_sitearch}/xpra/platform/graph.py \
    %{buildroot}%{python_sitearch}/xpra/sound/pulseaudio_util.py \
    %{buildroot}%{python_sitearch}/xpra/gtk_view_keyboard.py
    
#fix permissions on shared objects
chmod 0755 \
    %{buildroot}%{python_sitearch}/xpra/wait_for_x_server.so \
    %{buildroot}%{python_sitearch}/xpra/xor/cyxor.so \
    %{buildroot}%{python_sitearch}/xpra/stats/cymaths.so \
    %{buildroot}%{python_sitearch}/xpra/rencode/_rencode.so \
    %{buildroot}%{python_sitearch}/wimpiggy/lowlevel/bindings.so \
    %{buildroot}%{python_sitearch}/wimpiggy/gdk/gdk_atoms.so

    
%check
desktop-file-validate %{buildroot}%{_datadir}/applications/xpra_launcher.desktop


%post
/usr/bin/update-desktop-database &> /dev/null || :
/bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :


%postun
/usr/bin/update-desktop-database &> /dev/null || :

if [ $1 -eq 0 ] ; then
    /bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    /usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
fi


%posttrans
/usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :


%files
%dir %{_sysconfdir}/xpra
%config(noreplace) %{_sysconfdir}/xpra/xorg.conf
%config(noreplace) %{_sysconfdir}/xpra/xpra.conf
%{_bindir}/xpra
%{_bindir}/xpra_Xdummy
%{_bindir}/xpra_launcher
%{python_sitearch}/xpra
%{_datadir}/applications/xpra_launcher.desktop
%{_datadir}/icons/hicolor/48x48/apps/xpra.png
%{_mandir}/man1/xpra.1.*
%{_mandir}/man1/xpra_launcher.1.*
%{_datadir}/xpra
%doc xpra.README NEWS

%files -n parti
%{_bindir}/parti
%{_bindir}/parti-repl
%{python_sitearch}/parti
%{python_sitearch}/parti_all-*.egg-info
%{_mandir}/man1/parti.1.*
%doc parti.README README NEWS

%files -n python-wimpiggy
%{python_sitearch}/wimpiggy
%doc COPYING wimpiggy.README NEWS


%changelog
* Thu Apr 11 2013 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.8.8-3
- drop unmet dependency on gstreamer-plugins-ugly
- fix permissions on shared objects
- add scriptlets necessary for icon/desktop file

* Thu Mar 28 2013 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.8.8-2
- disable codecs prohibited in Fedora

* Thu Mar 14 2013 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.8.8-1
- initial package
